Processor.App.OutStreamer.stream_to_file.OutStreamerFileHTMLContent — CommonCrawl Extractor 1.0 documentation

Toggle navigation sidebar
Toggle in-page Table of Contents

# Processor.App.OutStreamer.stream_to_file.OutStreamerFileHTMLContent

class Processor.App.OutStreamer.stream_to_file.OutStreamerFileHTMLContent(origin: Path, extension: str = '.html', **kwargs: Dict[Any, Any])
  __init__(origin: Path, extension: str = '.html', **kwargs: Dict[Any, Any])

  Methods

  `__init__`(origin[, extension]) |
  `clean_up`() |
  `get_file_name`(metadata) |
  `metadata_to_string`(extracted_data) |
  `stream`(extracted_data, metadata) |